@@ -11,4 +11,11 @@ releases.
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from sentry_sdk._types import Event, Hint  # noqa: F401
+    from sentry_sdk._types import Event, Hint
+else:
+    # The lines below allow the types to be imported from outside `if TYPE_CHECKING`
+    # guards. The types in this module are only intended to be used for type hints.
+    Event = None
+    Hint = None
+
+__all__ = ("Event", "Hint")
